/*
 * Copyright (c) 1993 Addison-Wesley Publishing Company.
 * All rights reserved.  This source code is provided
 * for its instructional value, and is not guaranteed
 * for any particular purpose.
 */
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <time.h>
#include <stdarg.h>
#include <string.h>

#define BUFSZ 1024
#define MAXLOGSZ 100000

static char buf[BUFSZ];
extern int logfd;

void
log(const char *fmt, ...)
{
	time_t t;
	char *tm;
	struct stat sbuf;
	va_list ap;

	/*
	 * Get the current time and convert it to a
	 * human-readable string.
	 */
	time(&t);
	tm = ctime(&t);

	/*
	 * Change newline to tab.  24 is location
	 * of newline.  25 is end of string.  Then
	 * copy the string to the buffer.
	 */
	tm[24] = '\t';
	strncpy(buf, tm, 25);

	/*
	 * Append the caller's string to the buffer.
	 */
	va_start(ap, fmt);
	vsprintf(buf+25, fmt, ap);
	va_end(ap);

	/*
	 * Add a newline.
	 */
	strcat(buf, "\n");

	/*
	 * If the log file is too large, truncate it to 0.
	 */
	if (fstat(logfd, &sbuf) == 0) {
		if (sbuf.st_size > MAXLOGSZ)
			ftruncate(logfd, 0);
	}

	/*
	 * Write the log message.
	 */
	write(logfd, buf, strlen(buf));
}
