/*
 * Copyright (c) 1993 Addison-Wesley Publishing Company.
 * All rights reserved.  This source code is provided
 * for its instructional value, and is not guaranteed
 * for any particular purpose.
 */
/* netpath.c */
#include <sys/types.h>
#include <stdlib.h>
#include <stdio.h>
#include <netconfig.h>

void
main()
{
	struct netconfig *ncp;
	void *p;
	int i;

	/*
	 * Gain access to /etc/netconfig.
	 */
	if ((p = setnetpath()) == NULL) {
		nc_perror("setnetpath failed");
		exit(1);
	}

	/*
	 * Get each entry as specified by NETPATH,
	 * and print the information.
	 */
	while ((ncp = getnetpath(p)) != NULL) {
		printf("network: %s\n\tsemantics = ",
		  ncp->nc_netid);
		switch (ncp->nc_semantics) {
		case NC_TPI_CLTS:
			printf("connectionless transport\n");
			break;

		case NC_TPI_COTS:
			printf("connection-oriented transport\n");
			break;

		case NC_TPI_COTS_ORD:
			printf("connection-oriented transport\n");
			printf("\t\t\twith orderly release\n");
			break;

		case NC_TPI_RAW:
			printf("raw transport\n");
			break;

		default:
			printf("unknown (%d)\n", ncp->nc_semantics);
		}
		printf("\tflags =");
		if (ncp->nc_flag == NC_NOFLAG)
			printf(" none\n");
		else if (ncp->nc_flag & NC_VISIBLE)
			printf(" visible\n");
		else
			printf(" unknown (0x%x)\n", ncp->nc_flag);
		printf("\tprotocol family = %s\n",
		  ncp->nc_protofmly);
		printf("\tprotocol = %s\n", ncp->nc_proto);
		printf("\tdevice = %s\n", ncp->nc_device);
		printf("\tnlookups = %d\n", ncp->nc_nlookups);
		if (ncp->nc_nlookups > 0) {
			printf("\tdirectory lookup libraries:\n");
			for (i = 0; i < ncp->nc_nlookups; i++)
				printf("\t\t%s\n", ncp->nc_lookups[i]);
		}
	}
	exit(0);
}
